
XEP-0385: Stateless Inline Media Sharing (SIMS)
===============================================

.. module:: slixmpp.plugins.xep_0385

.. autoclass:: XEP_0385
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0385.stanza
    :members:
    :undoc-members:

